@@ -160,17 +160,29 @@ static void cb_trad2sim()
   system(GCIN_BIN_DIR"/trad2sim &");
 }
 
+
+static void cb_tog_phospeak(GtkCheckMenuItem *checkmenuitem, gpointer *dat)
+{
+  phonetic_speak= gtk_check_menu_item_get_active(checkmenuitem);
+}
+
+void kbm_toggle();
+
 struct {
   char *name;
   char *stock_id;
   void (*cb)();
+  int *check_dat;
 } mitems[] = {
   {"設定", GTK_STOCK_PREFERENCES, exec_gcin_setup},
+  {"念出發音", NULL, cb_tog_phospeak, &phonetic_speak},
   {"正->簡體", NULL, cb_trad2sim},
   {"簡->正體", NULL, cb_sim2trad},
+  {"小鍵盤", NULL, kbm_toggle},
 };
 
 
+
 static GtkWidget *tray_menu;
 
 static void create_menu()
@@ -183,7 +195,12 @@ static void create_menu()
 
     if (mitems[i].stock_id) {
       item = gtk_image_menu_item_new_with_label (mitems[i].name);
-      gtk_image_menu_item_set_image(item, gtk_image_new_from_stock(mitems[i].stock_id, GTK_ICON_SIZE_MENU));
+      gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), gtk_image_new_from_stock(mitems[i].stock_id, GTK_ICON_SIZE_MENU));
+    }
+    else
+    if (mitems[i].check_dat) {
+      item = gtk_check_menu_item_new_with_label (mitems[i].name);
+      gtk_check_menu_item_set_active(item, *mitems[i].check_dat);
     }
     else
       item = gtk_menu_item_new_with_label (mitems[i].name);
