@@ -325,7 +325,9 @@ void disp_tsin_eng_pho(int eng_pho);
 
 void show_stat()
 {
+#if TRAY_ENABLED
   load_tray_icon();
+#endif
   disp_tsin_eng_pho(eng_ph);
 }
 
@@ -873,7 +875,9 @@ void tsin_set_eng_ch(int nmod)
   drawcursor();
 
   show_button_pho(eng_ph);
+#if TRAY_ENABLED
   load_tray_icon();
+#endif
 #if 0
   show_win0();
 #endif
@@ -1100,6 +1104,23 @@ void add_to_tsin_buf_str(char *str)
   add_to_tsin_buf(str, pho, N);
 }
 
+int tsin_sele_by_idx(int c)
+{
+  int len = pre_sel[c].len;
+
+  if (c >= pre_selN)
+    return 0;
+
+#if 0
+    dbg("eqlenN:%d %d\n", eqlenN, current_ph_idx);
+#endif
+
+  full_match = FALSE;
+  gboolean b_added = add_to_tsin_buf_phsta(pre_sel[c].str, pre_sel[c].phokey, len);
+
+  return b_added;
+}
+
 
 static gboolean pre_sel_handler(KeySym xkey)
 {
@@ -1126,19 +1147,7 @@ static gboolean pre_sel_handler(KeySym xkey)
 
   c = p - phkbm.selkey;
 
-  int len = pre_sel[c].len;
-
-  if (c >= pre_selN)
-    return 0;
-
-#if 0
-    dbg("eqlenN:%d %d\n", eqlenN, current_ph_idx);
-#endif
-
-  full_match = FALSE;
-  gboolean b_added = add_to_tsin_buf_phsta(pre_sel[c].str, pre_sel[c].phokey, len);
-
-  return b_added;
+  return tsin_sele_by_idx(c);
 }
 
 
@@ -1321,6 +1330,10 @@ int feedkey_pp(KeySym xkey, int kbstate)
   int shift_m=kbstate&ShiftMask;
   int j,jj,kk, idx;
   char kno;
+  int caps_eng_tog = tsin_chinese_english_toggle_key == TSIN_CHINESE_ENGLISH_TOGGLE_KEY_CapsLock;
+
+  if (caps_eng_tog)
+    eng_ph = !(kbstate&LockMask);
 
   key_press_time = 0;
 
@@ -1333,7 +1346,14 @@ int feedkey_pp(KeySym xkey, int kbstate)
 
    if (!eng_ph && !c_len && gcin_pop_up_win && xkey!=XK_Caps_Lock) {
      hide_win0();
-     return 0;
+
+     if (caps_eng_tog && xkey>=' ' && xkey<0x7f) {
+       case_inverse(&xkey, shift_m);
+       send_ascii(xkey);
+       return 1;
+     }
+     else
+       return 0;
    }
 
    int o_sel_pho = sel_pho;
@@ -1389,7 +1409,7 @@ int feedkey_pp(KeySym xkey, int kbstate)
      case XK_Right:
         return cursor_right();
      case XK_Caps_Lock:
-        if (tsin_chinese_english_toggle_key == TSIN_CHINESE_ENGLISH_TOGGLE_KEY_CapsLock) {
+        if (caps_eng_tog) {
           close_selection_win();
           tsin_toggle_eng_ch();
           return 1;
@@ -1597,9 +1617,6 @@ other_keys:
            return cursor_delete();
        }
 
-       if (tsin_space_opt == TSIN_SPACE_OPT_INPUT)
-         xkey_lcase = keypad_proc(xkey);
-
        char *pp;
        if ((pp=strchr(phkbm.selkey,xkey_lcase)) && sel_pho) {
          int c=pp-phkbm.selkey;
@@ -1659,6 +1676,10 @@ other_keys:
    }
 
    KeySym key_pad = keypad_proc(xkey);
+
+   if (xkey > 0x7e && !key_pad)
+     return 0;
+
    if (!eng_ph || typ_pho[0]!=BACK_QUOTE_NO && (shift_m || key_pad || !phkbm.phokbm[xkey][0].num)) {
        if (key_pad)
          xkey = key_pad;
@@ -1673,19 +1694,19 @@ asc_char:
             return 1;
         }
 
-
-//        dbg("xkey: %c\n", xkey);
-
         if (shift_m && eng_ph)  {
           char *ppp=strchr(ochars,xkey);
 
           if (!(kbstate&LockMask) && ppp && !((ppp-ochars) & 1))
             xkey=*(ppp+1);
+
+#if 0
           if (kbstate&LockMask && islower(xkey))
             xkey-=0x20;
           else
             if (!(kbstate&LockMask) && isupper(xkey))
               xkey+=0x20;
+#endif
         } else {
           if (!eng_ph && tsin_chinese_english_toggle_key == TSIN_CHINESE_ENGLISH_TOGGLE_KEY_CapsLock
               && gcin_capslock_lower) {
@@ -1702,7 +1723,6 @@ asc_char:
         if (tsin_half_full) {
           bchcpy(chpho[c_idx].ch, half_char_to_full_char(xkey));
         } else {
-//          dbg("%c\n", tt);
           chpho[c_idx].ch[0]=tt;
         }
 
@@ -1727,6 +1747,7 @@ asc_char:
        return 0;
      }
 
+
      // for hsu & et26
      if (strchr(hsu_punc, xkey) && !phkbm.phokbm[xkey][0].num && typ_pho[0]!=BACK_QUOTE_NO)
        return pre_punctuation_hsu(xkey);
@@ -1834,7 +1855,6 @@ llll2:
    drawcursor();
    hide_pre_sel();
 
-
    if (ph_sta < 0) {
 restart:
      if ((match_len=scanphr(c_idx-1,1, FALSE)))
@@ -1951,7 +1971,6 @@ restart:
          if (pre_selN == 1)
            pre_selN = 0;
        }
-
        return 1;
      }
    }
